LOLcat
======

Straight Python port of the Ruby version at https://github.com/busyloop/lolcat/
using not even half the code and no external dependancies.

It's a tool like cat, with added lulz.


Installing
==========

To install the stable version:

    $ pip install lolcat


To install the development version:

    $ pip install git+https://github.com/tehmaze/lolcat.git


Usage and examples
==================

![](https://github.com/tehmaze/lolcat/raw/master/lolcat.png)


Demo
====

Check out the ASCII cast at http://ascii.io/a/1563


Bugs
====

https://github.com/tehmaze/lolcat/issues
